@@ -13,9 +13,9 @@
 #define _CONST_H_
 
 
-#define APPNAME		"slim"
+#define APPNAME    "slim"
 
-#define DISPLAY		":0.0"
+#define DISPLAY    ":0.0"
 
 #define CONSOLE_STR     "console"
 #define HALT_STR        "halt"
@@ -23,23 +23,14 @@
 #define EXIT_STR        "exit"
 #define SUSPEND_STR     "suspend"
 
-#define HIDE		0
-#define SHOW		1
-
-#define WAIT		0
-#define LOGIN		1
-#define FAIL		2
-#define CONSOLE		3
-#define REBOOT		4
-#define HALT		5
-#define EXIT		6
-#define SUSPEND		7
+#define HIDE        0
+#define SHOW        1
 
 #define GET_NAME    0
-#define GET_PASSWD	1
+#define GET_PASSWD  1
 
-#define	OK_EXIT		0
-#define	ERR_EXIT	1
+#define OK_EXIT     0
+#define ERR_EXIT    1
 
 // duration for showing error messages, as "login command failed", in seconds
 #define ERROR_DURATION  5
