@@ -8,7 +8,7 @@
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
 */
-
+    
 #ifndef _SWITCHUSER_H_
 #define _SWITCHUSER_H_
 
@@ -25,7 +25,8 @@
 
 class SwitchUser {
 public:
-    SwitchUser(struct passwd *pw, Cfg *c, const std::string& display);
+    SwitchUser(struct passwd *pw, Cfg *c, const std::string& display,
+               char** _env);
     ~SwitchUser();
     void Login(const char* cmd, const char* mcookie);
 
@@ -34,13 +35,12 @@ private:
     void SetEnvironment();
     void SetUserId();
     void Execute(const char* cmd);
-    char* BaseName(const char* name);
-    char* StrConcat(const char* str1, const char* str2);
     void SetClientAuth(const char* mcookie);
     Cfg* cfg;
     struct passwd *Pw;
 
     std::string displayName;
+    char** env;
 };
 
 
